Welcome to Sorcha's community utilities documentation!
======================================================

Sorcha Community Utils is a collection of plugins for Sorcha that can be used to
model changes to the magnitude of objects in the solar system simulation.

.. toctree::
   :hidden:

   Home page <self>
   Usage <usage>
   Community Modules <community_modules>
   Notebooks <notebooks>
   Contributing <contributing>
   API Reference <autoapi/index>
